autots.datasets package — AutoTS 0.2.1 documentation

# autots.datasets package

## Submodules

## autots.datasets.fred module

FRED (Federal Reserve Economic Data) Data Import

requires API key from FRED and pip install fredapi

`autots.datasets.fred.` `get_fred_data`(fredkey: str, SeriesNameDict: dict = {'SeriesID': 'SeriesName'})

  Imports Data from Federal Reserve

  Parameters

    - - an API key from FRED (fredkey) –

    - pairs of FRED Series IDs and Series Names (SeriesNameDict,) – Series id must match Fred IDs, but name can be anything if default is use, several default samples are returned

## Module contents

Tools for Importing Sample Data

`autots.datasets.` `load_daily`()

  4 series of sample daily data from late 2019.

`autots.datasets.` `load_monthly`()

  Federal Reserve of St. Louis monthly economic indicators.

`autots.datasets.` `load_yearly`()

  Federal Reserve of St. Louis annual economic indicators.

`autots.datasets.` `load_hourly`()

  Traffic data from the MN DOT via the UCI data repository.

`autots.datasets.` `load_weekly`()

  Weekly petroleum industry data from the EIA.